@@ -1,7 +1,7 @@
 from mpmath.matrices import matrix, eye, swap_row, diag, mnorm_1, mnorm_oo, \
-    mnorm_F, norm_p, zeros, ones, randmatrix, extend
+    mnorm_F, norm_p, zeros, ones, hilbert, randmatrix, extend
 from mpmath.linalg import inverse
-from mpmath import inf, mpf, sqrt, mpi
+from mpmath import inf, mpf, sqrt, mpi, nstr
 
 with_numpy = False
 try:
@@ -35,8 +35,9 @@ def test_matrix_basic():
     A6 = matrix(l)
     assert A6.tolist() == l
     assert A6 == eval(repr(A6))
-    A6 = matrix(A6, force_type=float) 
+    A6 = matrix(A6, force_type=float)
     assert A6 == eval(repr(A6))
+    assert A6*1j == eval(repr(A6*1j))
     assert A3 * 10 == 10 * A3 == A6
     assert A2.rows == 3
     assert A2.cols == 2
@@ -68,6 +69,7 @@ def test_matrix_basic():
     A11 = matrix(randmatrix(2, 3), force_type=mpi)
     for a in A11:
         assert isinstance(a, mpi)
+    assert nstr(A9)
 
 def test_matrix_power():
     A = matrix([[1, 2], [3, 4]])
@@ -97,6 +99,10 @@ def test_matrix_creation():
     for a in A2:
         assert a == 0
     assert randmatrix(10) != randmatrix(10)
+    one = mpf(1)
+    assert hilbert(3) == matrix([[one, one/2, one/3],
+                                 [one/2, one/3, one/4],
+                                 [one/3, one/4, one/5]])
 
 def test_norms():
     # matrix norms
